@@ -1,7 +1,8 @@
 context('Coordinate transformation')
 
 test_that('Coordinates are reflected correctly', {
-  expect_equal( ReflectedEquivalents(0.01, 0.8, direction=1)[[1]], matrix(
+  expect_equal( ReflectedEquivalents(0.01, 0.8, direction = 1)[[1]], 
+                matrix(
     c(-0.06217968 , 0.84167296,
        0.05217968 , 0.82435245,
        0.01000000 ,-0.80000000,
@@ -14,9 +15,10 @@ test_that('Coordinates are reflected correctly', {
        -0.06217968,  0.89037785,
         1.43782032  ,0.02435245,
        -0.06217968, -0.84167296
-      ), ncol=2, byrow=TRUE))
+      ), ncol = 2, byrow = TRUE))
   
-  expect_equal(round(ReflectedEquivalents(0.8, 0.01, direction=2)[[1]], 5L), matrix(c(
+  expect_equal(round(ReflectedEquivalents(0.8, 0.01, direction = 2)[[1]], 5L),
+               matrix(c(
       0.82435,  0.05218,
       0.84167 ,-0.06218,
      -0.80000 , 0.01000,
@@ -31,7 +33,7 @@ test_that('Coordinates are reflected correctly', {
      -0.82435,  0.05218
   ), ncol=2, byrow=TRUE))
   
-  expect_equal(round(ReflectedEquivalents(0.01, -0.8, direction=3)[[1]], 5),
+  expect_equal(round(ReflectedEquivalents(0.01, -0.8, direction = 3)[[1]], 5),
                matrix(c(
      0.05218 ,-0.82435,
     -0.06218 ,-0.84167,
@@ -45,9 +47,10 @@ test_that('Coordinates are reflected correctly', {
      0.05218, -0.90770,
     -1.44782, -0.04167,
      0.05218,  0.82435
-  ), ncol=2, byrow=TRUE))
+  ), ncol = 2, byrow = TRUE))
   
-  expect_equal(round(ReflectedEquivalents(-0.13, 0.375, direction=4)[[1]], 5L), matrix(c(
+  expect_equal(round(ReflectedEquivalents(-0.13, 0.375, direction = 4)[[1]], 5L),
+               matrix(c(
     -0.17325 , 0.44992,
     -0.82277 ,-0.82492,
      0.13000 , 0.37500,
@@ -60,7 +63,14 @@ test_that('Coordinates are reflected correctly', {
     -1.55880,  0.44992,
     -0.69277 ,-1.05008,
      0.17325,  0.44992
-  ), ncol=2, byrow=TRUE))
+  ), ncol = 2, byrow = TRUE))
+})
+
+test_that("matrices can be coordinated", {
+  abc <- matrix(1:12, 3)
+  value <- TernaryToXY(abc)
+  expect_equivalent(apply(abc, 2, TernaryToXY), value)
+  expect_equal(c('x', 'y'), rownames(value))
 })
 
 test_that('Ranges are correct', {
